searchData={"items":[{"type":"module","title":"EctoCommons","doc":"`EctoCommons` contains common validators and formatters,\nmainly to be used with `Ecto.Changeset`s","ref":"EctoCommons.html"},{"type":"module","title":"EctoCommons.DateTimeValidator","doc":"This module provides validators for `DateTime`s.\n\nYou can use the following checks:\n\n  * `:is` to check if a `DateTime` is exactly some `DateTime`. You can also provide a `:delta` option (in seconds)\n     to specify a delta around which the `DateTime` is still considered identical.\n  * `:before` to check if a `DateTime` is before some `DateTime`\n  * `:after` to check if a `DateTime` is after some `DateTime`\n\nYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error\nencountered will be returned and subsequent checks will be skipped.\nIf you want to check everything at once, you'll need to call this validator multiple times.\n\nAlso, instead of providing a `DateTime`, you can also provide some special atoms:\n\n  * `:utc_now` will compare the given `DateTime` with the `DateTime` at runtime, by calling `DateTime.utc_now()`.","ref":"EctoCommons.DateTimeValidator.html"},{"type":"module","title":"Example: - EctoCommons.DateTimeValidator","doc":"iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate)\n    #Ecto.Changeset \n\n    # Using :is to ensure a date is identical to another date\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, is: ~U[2016-05-24 13:26:08Z])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, is: ~U[2017-05-24 13:26:08Z])\n    #Ecto.Changeset \n\n    # Using :is with :delta to ensure a date is near another another date\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, is: ~U[2016-05-24 13:46:08Z], delta: 3600)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 15:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, is: ~U[2016-05-24 13:26:08Z], delta: 3600)\n    #Ecto.Changeset \n\n    # Using :before to ensure date is before given date\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, before: ~U[2017-05-24 00:00:00Z])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, before: ~U[2015-05-24 00:00:00Z])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, before: :utc_now)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[3000-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, before: :utc_now)\n    #Ecto.Changeset \n\n    # Using :after to ensure date is after given date\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, after: ~U[2015-05-24 00:00:00Z])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[2016-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, after: ~U[2017-05-24 00:00:00Z])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[3000-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, after: :utc_now)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :utc_datetime}\n    iex> params = %{birthdate: ~U[1000-05-24 13:26:08Z]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_datetime(:birthdate, after: :utc_now)\n    #Ecto.Changeset","ref":"EctoCommons.DateTimeValidator.html#module-example"},{"type":"function","title":"EctoCommons.DateTimeValidator.validate_datetime/3","doc":"","ref":"EctoCommons.DateTimeValidator.html#validate_datetime/3"},{"type":"module","title":"EctoCommons.DateValidator","doc":"This module provides validators for `Date`s.\n\nYou can use the following checks:\n\n  * `:is` to check if a `Date` is exactly some `Date`. You can also provide a `:delta` option (in days)\n     to specify a delta around which the `Date` is still considered identical.\n  * `:before` to check if a `Date` is before some `Date`\n  * `:after` to check if a `Date` is after some `Date`\n\nYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error\nencountered will be returned and subsequent checks will be skipped.\nIf you want to check everything at once, you'll need to call this validator multiple times.\n\nAlso, instead of providing a `Date`, you can also provide some special atoms:\n\n  * `:utc_today` will compare the given `Date` with the `Date` at runtime, by calling `Date.utc_today()`.","ref":"EctoCommons.DateValidator.html"},{"type":"module","title":"Example: - EctoCommons.DateValidator","doc":"iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate)\n    #Ecto.Changeset \n\n    # Using :is to ensure a date is identical to another date\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, is: ~D[2016-05-24])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, is: ~D[2017-05-24])\n    #Ecto.Changeset \n\n    # Using :is with :delta to ensure a date is near another another date\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-20]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, is: ~D[2016-05-24], delta: 7)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-04-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, is: ~D[2016-05-24], delta: 7)\n    #Ecto.Changeset \n\n    # Using :before to ensure date is before given date\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, before: ~D[2017-05-24])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, before: ~D[2015-05-24])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, before: :utc_today)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[3000-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, before: :utc_today)\n    #Ecto.Changeset \n\n    # Using :after to ensure date is after given date\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, after: ~D[2015-05-24])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[2016-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, after: ~D[2017-05-24])\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[3000-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, after: :utc_today)\n    #Ecto.Changeset \n\n    iex> types = %{birthdate: :date}\n    iex> params = %{birthdate: ~D[1000-05-24]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_date(:birthdate, after: :utc_today)\n    #Ecto.Changeset","ref":"EctoCommons.DateValidator.html#module-example"},{"type":"function","title":"EctoCommons.DateValidator.validate_date/3","doc":"","ref":"EctoCommons.DateValidator.html#validate_date/3"},{"type":"module","title":"EctoCommons.EmailValidator","doc":"Validates emails.","ref":"EctoCommons.EmailValidator.html"},{"type":"module","title":"Options - EctoCommons.EmailValidator","doc":"There are various `:checks` depending on the strictness of the validation you require. Indeed, perfect email validation\ndoes not exist (see StackOverflow questions about it):\n\n- `:html_input`: Checks if the email follows the regular expression used by browsers for\n  their `type=\"email\"` input fields. This is the default as it corresponds to most use-cases. It is quite strict\n  without being too narrow. It does not support unicode emails though. If you need better internationalization,\n  please use the `:pow` check as it is more flexible with international emails. Defaults to enabled.\n- `:burner`: Checks if the email given is a burner email provider (uses the `Burnex` lib under the hood).\n  When enabled, will reject temporary email providers. Defaults to disabled.\n- `:check_mx_record`: Checks if the email domain exists in the DNS system (can be a bit slow).\n- `:pow`: Checks the email using the [`pow`](https://hex.pm/packages/pow) logic. Defaults to disabled.\n  The rules are the following:\n  - Split into local-part and domain at last `@` occurrence\n  - Local-part should;\n    - be at most 64 octets\n    - separate quoted and unquoted content with a single dot\n    - only have letters, digits, and the following characters outside quoted\n      content:\n        ```text\n        !#$%&'*+-/=?^_`{|}~.\n        ```\n    - not have any consecutive dots outside quoted content\n  - Domain should;\n    - be at most 255 octets\n    - only have letters, digits, hyphen, and dots\n\n  Unicode characters are permitted in both local-part and domain.\n\n  The implementation is based on [RFC 3696](https://tools.ietf.org/html/rfc3696#section-3).\n  IP addresses are not allowed as per the RFC 3696 specification: \"The domain name can also be\n  replaced by an IP address in square brackets, but that form is strongly discouraged except\n  for testing and troubleshooting purposes.\".\n\n  You're invited to compare the tests to see the difference between the `:html_input`\n  check and the `:pow` check. `:pow` is better suited for i18n and is more correct\n  in regards to the email specification but will allow valid emails many systems don't\n  manage correctly. `:html_input` is more basic but should be OK for most common use-cases.","ref":"EctoCommons.EmailValidator.html#module-options"},{"type":"module","title":"Example: - EctoCommons.EmailValidator","doc":"iex> types = %{email: :string}\n    iex> params = %{email: \"valid.email@example.com\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_email(:email)\n    #Ecto.Changeset \n\n    iex> types = %{email: :string}\n    iex> params = %{email: \"@invalid_email\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_email(:email)\n    #Ecto.Changeset \n\n    iex> types = %{email: :string}\n    iex> params = %{email: \"uses_a_forbidden_provider@yopmail.net\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_email(:email, checks: [:html_input, :burner])\n    #Ecto.Changeset \n\n    iex> types = %{email: :string}\n    iex> params = %{email: \"uses_a_forbidden_provider@yopmail.net\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_email(:email, checks: [:html_input, :pow])\n    #Ecto.Changeset","ref":"EctoCommons.EmailValidator.html#module-example"},{"type":"function","title":"EctoCommons.EmailValidator.validate_email/3","doc":"","ref":"EctoCommons.EmailValidator.html#validate_email/3"},{"type":"module","title":"EctoCommons.Helpers","doc":"Contains helpers related to Ecto.\n\nSee functions contained in the module for more info.","ref":"EctoCommons.Helpers.html"},{"type":"function","title":"EctoCommons.Helpers.validate_many/4","doc":"This allows for validating multiple fields with the same validator function\nwith the same options for all fields.","ref":"EctoCommons.Helpers.html#validate_many/4"},{"type":"function","title":"Example - EctoCommons.Helpers.validate_many/4","doc":"iex> types = %{first_name: :string, last_name: :string}\n    iex> params = %{first_name: \"John\", last_name: \"Doe\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_many(\n    ...>   [:first_name, :last_name],\n    ...>   &Ecto.Changeset.validate_length/3,\n    ...>   min: 2,\n    ...>   max: 20\n    ...> )\n    #Ecto.Changeset \n\n    iex> types = %{first_name: :string, last_name: :string}\n    iex> params = %{first_name: \"J\", last_name: \"DoppelgängerDoppelgänger\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_many(\n    ...>   [:first_name, :last_name],\n    ...>   &Ecto.Changeset.validate_length/3,\n    ...>   min: 2,\n    ...>   max: 20,\n    ...>   message: \"this field is invalid\"\n    ...> )\n    #Ecto.Changeset","ref":"EctoCommons.Helpers.html#validate_many/4-example"},{"type":"module","title":"EctoCommons.LuhnValidator","doc":"This ecto validator checks the provided value is valid\nusing the Luhn algorithm. This is useful for credit cards and other\ncommon administrative values.\n\nThe validator accepts an optional `:transformer` function\nthat can modify the value before applying the Luhn check. This is\nuseful in cases where the input value contains other characters\nor letters instead of only numbers. The transformed value will\nbe Luhn-checked without replacing the value provided in the params.","ref":"EctoCommons.LuhnValidator.html"},{"type":"module","title":"Example: - EctoCommons.LuhnValidator","doc":"iex> types = %{admin_code: :string}\n    iex> params = %{admin_code: \"740123450\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_luhn(:admin_code)\n    #Ecto.Changeset \n\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"74012345123456\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_luhn(:admin_id)\n    #Ecto.Changeset \n\n    iex> types = %{admin_code: :string}\n    iex> params = %{admin_code: \"7A0123450\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_luhn(:admin_code, transformer: &(String.replace(&1, \"7A\", \"74\")))\n    #Ecto.Changeset \n\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"this is an incorrect value\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_luhn(:admin_id)\n    #Ecto.Changeset","ref":"EctoCommons.LuhnValidator.html#module-example"},{"type":"function","title":"EctoCommons.LuhnValidator.validate_luhn/3","doc":"","ref":"EctoCommons.LuhnValidator.html#validate_luhn/3"},{"type":"module","title":"EctoCommons.PhoneNumberValidator","doc":"Validate a phone number.\n\nThis validator uses libphonenumber under the hood to\nvalidate phone numbers.\n\nThis validator expects a `:country` argument to be passed\nso it can check the number corresponds to the given country.\n\nIf you pass it `\"\"` or `nil` it won't complain as long as the number\nis a valid E164 format that can be parsed without the country info.","ref":"EctoCommons.PhoneNumberValidator.html"},{"type":"module","title":"Examples - EctoCommons.PhoneNumberValidator","doc":"iex> types = %{phone_number: :string}\n    iex> params = %{phone_number: \"0610234567\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_phone_number(:phone_number, country: \"fr\")\n    #Ecto.Changeset \n\n    iex> types = %{phone_number: :string}\n    iex> params = %{phone_number: \"798765432L\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_phone_number(:phone_number, country: \"ch\")\n    #Ecto.Changeset \n\n    # Country can be ignored in E164 formatted numbers\n    iex> types = %{phone_number: :string}\n    iex> params = %{phone_number: \"+16502530000\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_phone_number(:phone_number)\n    #Ecto.Changeset \n\n    iex> types = %{phone_number: :string}\n    iex> params = %{phone_number: \"01 23 45 67 89\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_phone_number(:phone_number, country: nil)\n    #Ecto.Changeset","ref":"EctoCommons.PhoneNumberValidator.html#module-examples"},{"type":"function","title":"EctoCommons.PhoneNumberValidator.validate_phone_number/3","doc":"","ref":"EctoCommons.PhoneNumberValidator.html#validate_phone_number/3"},{"type":"module","title":"EctoCommons.PostalCodeValidator","doc":"Validate the postal code within a country context.\n\nThis validator will only validate the postal code against known\nregex formats for a given country, it won't match the postal\ncode to an actual database of all available postal codes in each country.","ref":"EctoCommons.PostalCodeValidator.html"},{"type":"module","title":"Examples - EctoCommons.PostalCodeValidator","doc":"iex> types = %{postal_code: :string}\n    iex> params = %{postal_code: \"69001\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_postal_code(:postal_code, country: \"fr\")\n    #Ecto.Changeset \n\n    iex> types = %{postal_code: :string}\n    iex> params = %{postal_code: \"1120\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_postal_code(:postal_code, country: \"be\")\n    #Ecto.Changeset \n\n    iex> types = %{postal_code: :string}\n    iex> params = %{postal_code: \"00199\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_postal_code(:postal_code, country: \"it\")\n    #Ecto.Changeset \n\n    iex> types = %{postal_code: :string}\n    iex> params = %{postal_code: \"28010\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_postal_code(:postal_code, country: \"es\")\n    #Ecto.Changeset \n\n    iex> types = %{postal_code: :string}\n    iex> params = %{postal_code: \"1211\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_postal_code(:postal_code, country: \"ch\")\n    #Ecto.Changeset","ref":"EctoCommons.PostalCodeValidator.html#module-examples"},{"type":"function","title":"EctoCommons.PostalCodeValidator.get_regexp/1","doc":"","ref":"EctoCommons.PostalCodeValidator.html#get_regexp/1"},{"type":"function","title":"EctoCommons.PostalCodeValidator.validate_postal_code/3","doc":"","ref":"EctoCommons.PostalCodeValidator.html#validate_postal_code/3"},{"type":"module","title":"EctoCommons.SocialSecurityValidator","doc":"This ecto validator checks the provided value is a\nvalid social security number for a given country","ref":"EctoCommons.SocialSecurityValidator.html"},{"type":"module","title":"Example: - EctoCommons.SocialSecurityValidator","doc":"iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"188037424305025\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_social_security(:admin_id, country: \"fr\")\n    #Ecto.Changeset \n\n    # Also works for temporary french social security numbers and special edge cases (corsica)\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"7 56 50 2B 233 042 82\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_social_security(:admin_id, country: \"fr\")\n    #Ecto.Changeset \n\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"8 12 50 97 307 437 59\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_social_security(:admin_id, country: \"fr\")\n    #Ecto.Changeset \n\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"1 88 03 74 243 050 57\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_social_security(:admin_id, country: \"fr\")\n    #Ecto.Changeset \n\n    iex> types = %{admin_id: :string}\n    iex> params = %{admin_id: \"this is an incorrect value\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_social_security(:admin_id, country: \"fr\")\n    #Ecto.Changeset","ref":"EctoCommons.SocialSecurityValidator.html#module-example"},{"type":"function","title":"EctoCommons.SocialSecurityValidator.checksum/2","doc":"","ref":"EctoCommons.SocialSecurityValidator.html#checksum/2"},{"type":"function","title":"EctoCommons.SocialSecurityValidator.split_checksum/2","doc":"","ref":"EctoCommons.SocialSecurityValidator.html#split_checksum/2"},{"type":"function","title":"EctoCommons.SocialSecurityValidator.valid?/2","doc":"","ref":"EctoCommons.SocialSecurityValidator.html#valid?/2"},{"type":"function","title":"EctoCommons.SocialSecurityValidator.validate_social_security/3","doc":"","ref":"EctoCommons.SocialSecurityValidator.html#validate_social_security/3"},{"type":"module","title":"EctoCommons.StringValidator","doc":"This module provides validation for String / Text values\n\nThe following validators are available:\n\n  * `validate_has_prefix/3` which will check if a given field is prefixed\n    by some given fixed or dynamic string","ref":"EctoCommons.StringValidator.html"},{"type":"module","title":"Example: - EctoCommons.StringValidator","doc":"# Simple prefix\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: \"private\")\n    #Ecto.Changeset \n\n    # Prefix with separator\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: \"private\", separator: \"|\")\n    #Ecto.Changeset \n\n    # Wrong prefix\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: \"provider\")\n    #Ecto.Changeset \n\n    # Correct prefix but wrong separator\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: \"private\", separator: \"_\")\n    #Ecto.Changeset \n\n    # Dynamic prefix from function which is correct\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: fn _chgst, _opts -> \"private\" end)\n    #Ecto.Changeset \n\n    # Dynamic prefix from another changeset field\n    iex> types = %{token: :string, provider: :string}\n    iex> params = %{token: \"iamsvc|some-random-string-id\", provider: \"iamsvc\"}\n    iex> changeset = Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: fn chgst, _opts -> Ecto.Changeset.get_field(chgst, :provider) end)\n    iex> changeset.changes.provider\n    \"iamsvc\"\n    iex> changeset.changes.token\n    \"iamsvc|some-random-string-id\"\n    iex> changeset.valid?\n    true\n\n    # Dynamic prefix from another changeset field\n    iex> types = %{token: :string, provider: :string}\n    iex> params = %{token: \"some-random-string-id\", provider: nil}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: fn chgst, _opts -> Ecto.Changeset.get_field(chgst, :provider) end)\n    #Ecto.Changeset \n\n    # Dynamic prefix from function, which fails\n    iex> types = %{token: :string}\n    iex> params = %{token: \"private|some-random-string-id\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_has_prefix(:token, prefix: fn _chgst, _opts -> \"test\" end)\n    #Ecto.Changeset","ref":"EctoCommons.StringValidator.html#module-example"},{"type":"function","title":"EctoCommons.StringValidator.validate_has_prefix/3","doc":"","ref":"EctoCommons.StringValidator.html#validate_has_prefix/3"},{"type":"module","title":"EctoCommons.TimeValidator","doc":"This module provides validators for `Time`s.\n\nYou can use the following checks:\n\n  * `:is` to check if a `Time` is exactly some `Time`. You can also provide a `:delta` option (in seconds)\n     to specify a delta around which the `Time` is still considered identical.\n  * `:before` to check if a `Time` is before some `Time`\n  * `:after` to check if a `Time` is after some `Time`\n\nYou can also combine the given checks for complex checks. Errors won't be stacked though, the first error\nencountered will be returned and subsequent checks will be skipped.\nIf you want to check everything at once, you'll need to call this validator multiple times.\n\nAlso, instead of providing a `Time`, you can also provide some special atoms:\n\n  * `:utc_now` will compare the given `Time` with the `Time` at runtime, by calling `Time.utc_now()`.","ref":"EctoCommons.TimeValidator.html"},{"type":"module","title":"Example: - EctoCommons.TimeValidator","doc":"iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start)\n    #Ecto.Changeset \n\n    # Using :is to ensure a time is identical to another time\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, is: ~T[12:01:01])\n    #Ecto.Changeset \n\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, is: ~T[13:01:01])\n    #Ecto.Changeset \n\n    # Using :is with :delta to ensure a time is near another another time\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, is: ~T[12:15:01], delta: 900)\n    #Ecto.Changeset \n\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[13:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, is: ~T[12:01:01], delta: 900)\n    #Ecto.Changeset \n\n    # Using :before to ensure time is before given time\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, before: ~T[13:01:01])\n    #Ecto.Changeset \n\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, before: ~T[11:01:01])\n    #Ecto.Changeset \n\n    # Using :after to ensure time is after given time\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, after: ~T[11:01:01])\n    #Ecto.Changeset \n\n    iex> types = %{meeting_start: :time}\n    iex> params = %{meeting_start: ~T[12:01:01]}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_time(:meeting_start, after: ~T[13:01:01])\n    #Ecto.Changeset","ref":"EctoCommons.TimeValidator.html#module-example"},{"type":"function","title":"EctoCommons.TimeValidator.validate_time/3","doc":"","ref":"EctoCommons.TimeValidator.html#validate_time/3"},{"type":"module","title":"EctoCommons.URLValidator","doc":"This validator is used to validate URLs.","ref":"EctoCommons.URLValidator.html"},{"type":"module","title":"Options - EctoCommons.URLValidator","doc":"There are some available `:checks` depending on the strictness of what you want to validate:\n\n  - `:parsable`: Checks to see if the URL is parsable by `:http_uri.parse/1` Erlang function.\n     This can have issues with international URLs where it should be disabled (see tests). Defaults to enabled\n  - `:empty`: Checks to see if the parsed `%URI{}` struct is not empty (all fields set to nil). Defaults to enabled\n  - `:scheme`: Checks to see if the parsed `%URI{}` struct contains a `:scheme`. Defaults to enabled\n  - `:host`: Checks to see if the parsed `%URI{}` struct contains a `:host`. Defaults to enabled\n  - `:valid_host`: Does a `:inet.getbyhostname/1` call to check if the host exists. This will do a network call.\n     Defaults to disabled\n  - `:path`: Checks to see if the parsed `%URI{}` struct contains a `:path`. Defaults to disabled\n  - `:http_regexp`: Tries to match URL to a regexp known to catch many unwanted URLs (see code). It only accepts\n     HTTP(S) and FTP schemes though. Defaults to disabled\n\nThe approach is not yet very satisfactory IMHO, if you have suggestions, Pull Requests are welcome :)","ref":"EctoCommons.URLValidator.html#module-options"},{"type":"module","title":"Example: - EctoCommons.URLValidator","doc":"iex> types = %{url: :string}\n    iex> params = %{url: \"https://www.example.com/\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_url(:url)\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"https://www.example.com/\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_url(:url, checks: [:empty, :path, :scheme, :host])\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"some@invalid_url\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_url(:url)\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"Just some random text\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> validate_url(:url)\n    #Ecto.Changeset","ref":"EctoCommons.URLValidator.html#module-example"},{"type":"function","title":"EctoCommons.URLValidator.blank?/1","doc":"","ref":"EctoCommons.URLValidator.html#blank?/1"},{"type":"function","title":"EctoCommons.URLValidator.validate_url/3","doc":"","ref":"EctoCommons.URLValidator.html#validate_url/3"},{"type":"extras","title":"EctoCommons","doc":"# EctoCommons\n\n[![Build Status](https://github.com/achedeuzot/ecto_commons/workflows/tests/badge.svg)](https://github.com/achedeuzot/ecto_commons/actions?query=workflow%3Atests+branch%3Amaster) [![Coverage Status](https://coveralls.io/repos/github/achedeuzot/ecto_commons/badge.svg?branch=master)](https://coveralls.io/github/achedeuzot/ecto_commons?branch=master) [![Hex Version](https://img.shields.io/hexpm/v/ecto_commons.svg)](https://hex.pm/packages/ecto_commons) [![License](http://img.shields.io/badge/license-MIT-brightgreen.svg)](http://opensource.org/licenses/MIT)\n\nEcto common helpers such as validators and formatters.","ref":"readme.html"},{"type":"extras","title":"Installation - EctoCommons","doc":"The package is available on [hex](https://hex.pm/), so it can be installed\nby adding `ecto_commons` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_commons, \"~> 0.3.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Incompatibility Warning - EctoCommons","doc":"In order to check whether URLs are parseable,\nthis library requires either a recent (>= 1.13.0) of Elixir,\nor an older (< 26) version of OTP.","ref":"readme.html#incompatibility-warning"},{"type":"extras","title":"Documentation - EctoCommons","doc":"Documentation is published on [HexDocs](https://hexdocs.pm) and can\nbe found at [https://hexdocs.pm/ecto_commons](https://hexdocs.pm/ecto_commons).","ref":"readme.html#documentation"},{"type":"extras","title":"Summary - EctoCommons","doc":"The package contains common ecto helpers:\n\n#","ref":"readme.html#summary"},{"type":"extras","title":"Changeset validators - EctoCommons","doc":"- `EctoCommons.DateValidator`:\n    - `validate_date(changeset, field, opts)`: validates an equality (with\n       approximation), before or after a given date.\n  - `EctoCommons.DateTimeValidator`\n    - `validate_datetime(changeset, field, opts)`: validates an equality (with\n       approximation), before or after a given date time.\n  - `EctoCommons.TimeValidator`\n    - `validate_time(changeset, field, opts)`: validates an equality (with\n       approximation), before or after a given time.\n  - `EctoCommons.EmailValidator`\n    - `validate_email(changeset, field, opts)`: validates emails. As there is no\n      perfect validation possible, multiple options are available depending\n      on your requirements. Can also reject temporary/burner emails.\n  - `EctoCommons.URLValidator`\n    - `validate_url(changeset, field, opts)`: validates if an URL is correct. Here\n      too, there is no perfection possible. Multiple options are available\n      depending on the precision required.\n  - `EctoCommons.StringValidator`\n    - `validate_has_prefix(changeset, field, opts)`: validates if a string starts\n      with a given prefix. The prefix itself can depend on another field or\n      on a dynamic value.\n  - `EctoCommons.PostalCodeValidator`\n    - `validate_postal_code(changeset, field, opts)`: validates postal code formatting\n      using regular expressions depending on the country. This only ensures the postal\n      code \"looks ok\" but doesn't check it really exists (that will need a complete\n      database of all postal codes worldwide).\n  - `EctoCommons.SocialSecurityValidator`\n    - `validate_social_security(changeset, field, opts)`: validates social security\n      numbers (SSN) depending on the country. This only validates french SSNs for now.\n  - `EctoCommons.LuhnValidator`\n    - `validate_luhn(changeset, field, opts)`: validates a string with Luhn's\n      algorithm such as credit card numbers and other administrative codes.\n  - `EctoCommons.PhoneNumberValidator`\n    - `validate_phone_number(changeset, field, opts)`: validates a phone number\n      using libphonenumber.","ref":"readme.html#changeset-validators"},{"type":"extras","title":"Changeset helpers - EctoCommons","doc":"- `EctoCommons.Helpers`\n   - `validate_many(changeset, field, opts)`: validates multiple fields with the same\n     validation function as well as the same options.","ref":"readme.html#changeset-helpers"},{"type":"extras","title":"Changelog - EctoCommons","doc":"`ecto_commons` follows semantic versioning. See [`CHANGELOG.md`](https://github.com/achedeuzot/ecto_commons/blob/master/CHANGELOG.md) for more information.","ref":"readme.html#changelog"},{"type":"extras","title":"Development - EctoCommons","doc":"Use [Earthly](https://earthly.dev/) to run tests against various versions of Elixir and Erlang.\n\n```sh\nearthly +all\n```","ref":"readme.html#development"},{"type":"extras","title":"License - EctoCommons","doc":"MIT. Please see [LICENSE](https://github.com/achedeuzot/ecto_commons/blob/master/LICENSE) for licensing details.","ref":"readme.html#license"}],"content_type":"text/markdown"}